# pyd: An updateable dict service for Python3, multi-pattern match

## Introduction

`pyd` is a python3 package of dict service, multi-pattern match, we also have a Golang version [https://github.com/liuzl/d](https://github.com/liuzl/d).

## Install

## Usage
